import { BaseRealm } from '@yukawa/chain-base-angular-domain';
import { MainRealm } from '@yukawa/chain-main-angular-core';
import * as i0 from '@angular/core';
import { forwardRef, Injectable, Inject, InjectionToken, inject, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpHeaders, HttpClient, HttpParams, HttpClientModule } from '@angular/common/http';
import { map } from 'rxjs/operators';
import * as i2 from '@yukawa/chain-base-angular-client';
import { RestAspect, ConfigService, RepoAspectRest, InterceptedRepoAspectsRest, CachedRepoAspectRest } from '@yukawa/chain-base-angular-client';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { FlexLayoutModule } from '@angular/flex-layout';
import * as i1$1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { MatRippleModule } from '@angular/material/core';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatTableModule } from '@angular/material/table';
import { MatSortModule } from '@angular/material/sort';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatMenuModule } from '@angular/material/menu';
import { MatCheckboxModule } from '@angular/material/checkbox';

// noinspection JSUnusedGlobalSymbols
/**
 * inc.yukawa.tracker.base.core.realm.TrackerRealm
 * @since 2.0.7
 **/
class TrackerRealm extends MainRealm {
}
TrackerRealm.ROLE_TRACKER_ADMIN = "ROLE_TRACKER_ADMIN";
TrackerRealm.ROLE_TRACKER_EDITOR = "ROLE_TRACKER_EDITOR";
TrackerRealm.ROLE_TRACKER_READER = "ROLE_TRACKER_READER";
TrackerRealm.ROLE_ATTACHMENT_EDITOR = "ROLE_ATTACHMENT_EDITOR";
TrackerRealm.ROLE_ATTACHMENT_READER = "ROLE_ATTACHMENT_READER";
TrackerRealm.ROLE_COMMENT_EDITOR = "ROLE_COMMENT_EDITOR";
TrackerRealm.ROLE_COMMENT_READER = "ROLE_COMMENT_READER";
TrackerRealm.ROLE_CONTACTLOG_EDITOR = "ROLE_CONTACTLOG_EDITOR";
TrackerRealm.ROLE_CONTACTLOG_READER = "ROLE_CONTACTLOG_READER";
TrackerRealm.ROLE_PROJECT_EDITOR = "ROLE_PROJECT_EDITOR";
TrackerRealm.ROLE_PROJECT_READER = "ROLE_PROJECT_READER";
TrackerRealm.ROLE_PROJECT_TEMPLATE_EDITOR = "ROLE_PROJECT_TEMPLATE_EDITOR";
TrackerRealm.ROLE_PROJECT_TEMPLATE_READER = "ROLE_PROJECT_TEMPLATE_READER";
TrackerRealm.ROLE_TASK_EDITOR = "ROLE_TASK_EDITOR";
TrackerRealm.ROLE_TASK_READER = "ROLE_TASK_READER";
TrackerRealm.ROLE_RISK_EDITOR = "ROLE_RISK_EDITOR";
TrackerRealm.ROLE_RISK_READER = "ROLE_RISK_READER";
TrackerRealm.ADMINS = [BaseRealm.ROLE_ADMIN, TrackerRealm.ROLE_TRACKER_ADMIN];
TrackerRealm.EDITORS = [...TrackerRealm.ADMINS, TrackerRealm.ROLE_TRACKER_EDITOR];
TrackerRealm.READERS = [...TrackerRealm.EDITORS, TrackerRealm.ROLE_TRACKER_READER];
TrackerRealm.PROJECT_READERS = [...TrackerRealm.READERS, TrackerRealm.ROLE_PROJECT_READER];
TrackerRealm.PROJECT_EDITORS = [...TrackerRealm.EDITORS, TrackerRealm.ROLE_PROJECT_EDITOR];
TrackerRealm.LABEL_EDITORS = [...TrackerRealm.EDITORS, TrackerRealm.ROLE_LABEL_ADMIN, TrackerRealm.ROLE_LABEL_EDIT];
TrackerRealm.LABEL_READERS = [...TrackerRealm.READERS, TrackerRealm.ROLE_LABEL_READ];

var ProjectPhase;
(function (ProjectPhase) {
    ProjectPhase["PHASE_PROJECT"] = "project";
    ProjectPhase["PHASE_LEAD"] = "lead";
    ProjectPhase["PHASE_PROPOSAL"] = "proposal";
})(ProjectPhase || (ProjectPhase = {}));
var Fep;
(function (Fep) {
    Fep["NEW"] = "NEW";
    Fep["REJECTED"] = "REJECTED";
    Fep["WAIT_FOR_CONFIRM"] = "WAIT_FOR_CONFIRM";
    Fep["CONFIRMED"] = "CONFIRMED";
})(Fep || (Fep = {}));
var AttachmentCategory;
(function (AttachmentCategory) {
    AttachmentCategory["INVOICE"] = "INVOICE";
})(AttachmentCategory || (AttachmentCategory = {}));
const projectPhases = [];
for (let n in ProjectPhase) {
    if (typeof ProjectPhase[n] === 'string') {
        projectPhases.push(ProjectPhase[n]);
    }
}
class Yukawa_LeanRealm extends TrackerRealm {
}
Yukawa_LeanRealm.ROLE_INVOICE_FEP_CONFIRM_PARTIAL = "ROLE_INVOICE_FEP_CONFIRM_PARTIAL";
Yukawa_LeanRealm.ROLE_INVOICE_FEP_REJECT = "ROLE_INVOICE_FEP_REJECT";
Yukawa_LeanRealm.ROLE_INVOICE_FEP_CONFIRM = "ROLE_INVOICE_FEP_CONFIRM";

class TaskUtils {
    /**
     * This function calculates the price/volume of a list of tasks
     *
     * @param subTasks List of tasks
     * @param projectRoles List of project roles containing the prices
     */
    static calculatePrice(subTasks, projectRoles) {
        let result = 0;
        for (let task of subTasks) {
            let hourlyRate = task.role.hourlyRate;
            let frequency = task.plannedBudget.amount;
            if (hourlyRate && frequency) {
                result += hourlyRate * frequency;
            }
        }
        return result;
    }
    static getProjectRoleHourlyRateMap(roles) {
        let dict = {};
        for (let role of roles) {
            dict[role.roleId] = role.hourlyRate;
        }
        return dict;
    }
}

class ProjectService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("projectUrl"));
    }
    // searchProject(filter: any): Observable<SearchResult<Project>> {
    //     return this.search<Project>(this.formatServiceUrl('/search'), filter);
    // }
    queryProject(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadProject(id) {
        return this.load(`${this.formatServiceUrl('')}?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveProject(project, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), project, { method: 'post' });
    }
    deleteProject(id) {
        return this.http.delete(`${this.formatServiceUrl('')}?key=${id}`);
    }
    updateProjectPhase(phase, projectId) {
        return this.http.post(`${this.formatServiceUrl('/phase')}?projectId=${projectId}`, phase);
    }
    newProject() {
        return this.http.post(`${this.formatServiceUrl('/new')}`, {})
            .pipe(map(value => this.checkNotNull(value)));
    }
    downloadPdf(projectId) {
        return this.http.post(`${this.formatServiceUrl('/generateProposal')}`, projectId);
    }
    mergeProject(project) {
        return this.http.post(this.formatServiceUrl('/merge'), project);
    }
    update(project) {
        return this.http.post(this.formatServiceUrl('/update'), project);
    }
    put(project) {
        return this.http.post(this.formatServiceUrl('/put'), project);
    }
    collectionPut(project) {
        return this.http.post(this.formatServiceUrl('/collection/put'), project);
    }
    collectionRemove(project) {
        return this.http.post(this.formatServiceUrl('/collection/remove'), project);
    }
    collectionsAppend(project) {
        return this.http.post(this.formatServiceUrl('/collections/append'), project);
    }
    export(filter) {
        let opts = {
            headers: new HttpHeaders({
                'Content-Type': 'application/json'
                //'Accept': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
            })
        };
        return this.download(`${this.formatServiceUrl('/export')}`, filter, opts);
    }
}
/** @nocollapse */ ProjectService.ɵfac = function ProjectService_Factory(t) { return new (t || ProjectService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ ProjectService.ɵprov = i0.ɵɵdefineInjectable({ token: ProjectService, factory: ProjectService.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(ProjectService, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class TaskService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("taskUrl"));
    }
    // searchTask(filter: any): Observable<SearchResult<Task>> {
    //     return this.search<Project>(this.formatServiceUrl('/search'), filter);
    // }
    queryTask(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadTask(id) {
        return this.load(`${this.formatServiceUrl('')}?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveTask(task, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), task, { method: 'post' });
    }
    mergeTask(task) {
        return this.edit(this.formatServiceUrl(`/merge`), task, { method: 'post' });
    }
    deleteTask(id) {
        return this.http.delete(`${this.formatServiceUrl()}/?key=${id}`);
    }
    generateInvoice(invoice) {
        return this.http.post(this.formatServiceUrl('/generateInvoice'), invoice);
    }
}
/** @nocollapse */ TaskService.ɵfac = function TaskService_Factory(t) { return new (t || TaskService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ TaskService.ɵprov = i0.ɵɵdefineInjectable({ token: TaskService, factory: TaskService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(TaskService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class ProjectSheetService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("projectSheetUrl"));
    }
    // searchProjectSheet(filter: any): Observable<SearchResult<ProjectSheet>> {
    //     return this.search<ProjectSheet>(this.formatServiceUrl('/search'), filter);
    // }
    queryProjectSheet(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadProjectSheet(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveProjectSheet(task, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), task, { method: 'post' });
    }
    deleteProjectSheet(id) {
        return this.http.delete(`${this.formatServiceUrl()}/?key=${id}`);
    }
}
/** @nocollapse */ ProjectSheetService.ɵfac = function ProjectSheetService_Factory(t) { return new (t || ProjectSheetService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ ProjectSheetService.ɵprov = i0.ɵɵdefineInjectable({ token: ProjectSheetService, factory: ProjectSheetService.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(ProjectSheetService, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class RiskService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("risksUrl"));
    }
    searchRisk(filter) {
        return this.search(this.formatServiceUrl('/search'), filter);
    }
    queryRisks(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadRisk(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveRisk(task, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), task, { method: 'post' });
    }
    deleteRisk(id) {
        return this.http.delete(`${this.formatServiceUrl()}/?key=${id}`);
    }
}
/** @nocollapse */ RiskService.ɵfac = function RiskService_Factory(t) { return new (t || RiskService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ RiskService.ɵprov = i0.ɵɵdefineInjectable({ token: RiskService, factory: RiskService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(RiskService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();

class AttachmentService extends RepoAspectRest {
    constructor(http, configService) {
        super(http, configService, 'attachmentUrl');
    }
    download(id, version) {
        return this.http.get(this.formatServiceUrl('/download/' + id), {
            responseType: 'blob'
        });
    }
    upload(attachment) {
        // @toDo * [ww] impl
        throw new Error('upload not implemented');
    }
    confirmAttachment(id) {
        return this.http.post(`${this.formatServiceUrl()}/fep/confirm?attachmentId=${id}`, null);
    }
    rejectAttachment(id) {
        return this.http.post(`${this.formatServiceUrl()}/fep/reject?attachmentId=${id}`, null);
    }
    // @toDo remove later
    deleteByKey(key) {
        // overloaded for this.formatServiceUrl('/')
        const queryParamsList = [];
        if (key !== undefined && key !== null) {
            queryParamsList.push({ name: 'key', value: key.toString() });
        }
        let params = new HttpParams();
        for (const queryParam of queryParamsList) {
            params = params.append(queryParam.name, queryParam.value);
        }
        return this.http.delete(this.formatServiceUrl('/'), { params });
    }
}
/** @nocollapse */ AttachmentService.ɵfac = function AttachmentService_Factory(t) { return new (t || AttachmentService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ AttachmentService.ɵprov = i0.ɵɵdefineInjectable({ token: AttachmentService, factory: AttachmentService.ɵfac, providedIn: "root" });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(AttachmentService, [{
        type: Injectable,
        args: [{ providedIn: "root" }]
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();

const PROJECT_ASPECT = new InjectionToken("Project aspect token");

const ORG_ID = new InjectionToken("injection token for the org id of the logged in user");
const PARTNERS = new InjectionToken("");
const partnersQueryObservableFactory = (partnerService) => {
    return partnerService.query({ pager: { firstResult: 0, pageSize: 10000 } }).pipe(map(res => res.items));
};

class DbtgProjectService extends InterceptedRepoAspectsRest {
    constructor(http, configService) {
        super(http, configService, "projectUrl");
        this.http = http;
        this.configService = configService;
    }
    beforeRead(filter) {
        return super.beforeRead(filter);
    }
    afterQuery(result) {
        return super.afterQuery(result);
    }
}

class DefaultProjectService extends InterceptedRepoAspectsRest {
    constructor(http, configService) {
        super(http, configService, "projectUrl");
        this.http = http;
        this.configService = configService;
    }
}

function projectAspectFactory() {
    const orgId = inject(ORG_ID);
    const configService = inject(ConfigService);
    const httpClient = inject(HttpClient);
    if (orgId.value === "dbtg") {
        return new DbtgProjectService(httpClient, configService);
    }
    else {
        return new DefaultProjectService(httpClient, configService);
    }
}

// services
class CoreModule {
    static forRoot() {
        return {
            ngModule: CoreModule,
            providers: [
                {
                    provide: PROJECT_ASPECT,
                    useFactory: projectAspectFactory,
                    deps: [ConfigService, HttpClient, ORG_ID]
                },
                ProjectService,
                ProjectSheetService,
                TaskService,
                AttachmentService,
                RiskService
            ]
        };
    }
}
/** @nocollapse */ CoreModule.ɵmod = i0.ɵɵdefineNgModule({ type: CoreModule });
/** @nocollapse */ CoreModule.ɵinj = i0.ɵɵdefineInjector({ factory: function CoreModule_Factory(t) { return new (t || CoreModule)(); }, providers: [], imports: [[
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatIconModule,
            MatRippleModule,
            MatSlideToggleModule,
            MatTableModule,
            MatSortModule,
            MatTooltipModule,
            FlexLayoutModule,
            MatMenuModule,
            MatCheckboxModule,
            HttpClientModule,
            TranslateModule.forChild()
        ]] });
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && i0.ɵɵsetNgModuleScope(CoreModule, { imports: [CommonModule,
        FormsModule,
        MatButtonModule,
        MatIconModule,
        MatRippleModule,
        MatSlideToggleModule,
        MatTableModule,
        MatSortModule,
        MatTooltipModule,
        FlexLayoutModule,
        MatMenuModule,
        MatCheckboxModule,
        HttpClientModule, i1$1.TranslateModule] }); })();
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(CoreModule, [{
        type: NgModule,
        args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    MatButtonModule,
                    MatIconModule,
                    MatRippleModule,
                    MatSlideToggleModule,
                    MatTableModule,
                    MatSortModule,
                    MatTooltipModule,
                    FlexLayoutModule,
                    MatMenuModule,
                    MatCheckboxModule,
                    HttpClientModule,
                    TranslateModule.forChild()
                ],
                declarations: [],
                exports: [],
                providers: [],
                entryComponents: [],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            }]
    }], null, null); })();

class CachedPartnerService extends CachedRepoAspectRest {
    constructor(http, configService) {
        super(http, configService, "partnerUrl", (partner) => partner.partnerId);
    }
}
/** @nocollapse */ CachedPartnerService.ɵfac = function CachedPartnerService_Factory(t) { return new (t || CachedPartnerService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(i2.ConfigService)); };
/** @nocollapse */ CachedPartnerService.ɵprov = i0.ɵɵdefineInjectable({ token: CachedPartnerService, factory: CachedPartnerService.ɵfac, providedIn: "root" });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(CachedPartnerService, [{
        type: Injectable,
        args: [{
                providedIn: "root"
            }]
    }], function () { return [{ type: i1.HttpClient }, { type: i2.ConfigService }]; }, null); })();

class CustomFieldIds {
}
CustomFieldIds.FUNDING_REQUEST_SUBMITTED = "FUNDING_REQUEST_SUBMITTED";
CustomFieldIds.FUNDING_PROGRAM = "FUNDING_PROGRAM";
CustomFieldIds.ZUW_BESCHEID = "ZUW_BESCHEID";
CustomFieldIds.APPLICATION_AMOUNT = "APPLICATION_AMOUNT";
CustomFieldIds.ASSOCIATION_FEE_PERCENT = "ASSOCIATION_FEE_PERCENT";
CustomFieldIds.ASSOCIATION_FEE_EURO = "ASSOCIATION_FEE_EURO";
CustomFieldIds.PLANNING_ORDER = "PLANNING_ORDER";
CustomFieldIds.PROJECT_STATUS = "PROJECT_STATUS";
CustomFieldIds.PROJECT_CATEGORY = "PROJECT_CATEGORY";
CustomFieldIds.SALES_PRODUCT = "SALES_PRODUCT";
CustomFieldIds.PLANNED_REALIZATION = "PLANNED_REALIZATION";
CustomFieldIds.PROJECT_PROVISION_PERCENT = "PROJECT_PROVISION_PERCENT";
CustomFieldIds.PROJECT_PROVISION_EURO = "PROJECT_PROVISION_EURO";
CustomFieldIds.NEXT_APPOINTMENT = "NEXT_APPOINTMENT";
CustomFieldIds.PROBABILITY = "PROBABILITY";
CustomFieldIds.EXPECTED_COMMISSIONING = "EXPECTED_COMMISSIONING";
CustomFieldIds.NUMBER_OF_FLOODLIGHTS = "NUMBER_OF_FLOODLIGHTS";
CustomFieldIds.NUMBER_OF_CHARGING_POINTS = "NUMBER_OF_CHARGING_POINTS";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_MAINTENANCE = "E_MOBILITY_SALES_PRODUCT_MAINTENANCE";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_DISTRIBUTION = "E_MOBILITY_SALES_PRODUCT_DISTRIBUTION";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_PLANNING_ORDER = "E_MOBILITY_SALES_PRODUCT_PLANNING_ORDER";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_BACKEND = "E_MOBILITY_SALES_PRODUCT_BACKEND";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_COMMERCE = "E_MOBILITY_SALES_PRODUCT_COMMERCE";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_INSTALLER = "E_MOBILITY_SALES_PRODUCT_INSTALLER";
CustomFieldIds.E_MOBILITY_SALES_PRODUCT_INVESTOR_MODEL = "E_MOBILITY_SALES_PRODUCT_INVESTOR_MODEL";

var ProjectCategory;
(function (ProjectCategory) {
    ProjectCategory["E_MOBILITY"] = "Elektromobilit\u00E4t";
    ProjectCategory["PHOTOVOLTAIC"] = "Photovoltaik";
    ProjectCategory["LED"] = "LED";
})(ProjectCategory || (ProjectCategory = {}));

var ProjectStatus;
(function (ProjectStatus) {
    ProjectStatus["FIRST_CONTACT"] = "Erstkontakt erfolgt";
    ProjectStatus["OFFER_IN_PROGRESS"] = "Angebot in Arbeit";
    ProjectStatus["FOLLOW_UP_ACQUISITION"] = "Nachakquise";
    ProjectStatus["OFFER_SENT"] = "Angebot versendet";
    ProjectStatus["REVISE_OFFER"] = "Angebot \u00FCberarbeiten";
    ProjectStatus["ORDER_CONFIRMATION_RECEIVED"] = "Auftragsbest\u00E4tigung erhalten";
    ProjectStatus["PREPAYMENT_RECEIVED"] = "Anzahlung erhalten";
    ProjectStatus["ORDER_RECIEVED"] = "Auftrag erhalten";
    ProjectStatus["FINAL_INVOICE"] = "Schlussrechnung gestellt";
})(ProjectStatus || (ProjectStatus = {}));

// Managers

/**
 * Generated bundle index. Do not edit.
 */

export { AttachmentCategory, AttachmentService, CachedPartnerService, CoreModule, CustomFieldIds, Fep, ORG_ID, PARTNERS, PROJECT_ASPECT, ProjectCategory, ProjectPhase, ProjectService, ProjectSheetService, ProjectStatus, RiskService, TaskService, TaskUtils, TrackerRealm, Yukawa_LeanRealm, partnersQueryObservableFactory, projectAspectFactory, projectPhases };
//# sourceMappingURL=yukawa-chain-tracker-angular-core.js.map
